OC.L10N.register(
    "mail",
    {
    "Mail" : "Փոստ",
    "Name" : "Անուն",
    "Password" : "Գաղտնաբառ",
    "Save" : "Պահպանել",
    "Connect" : "Միանալ",
    "Send" : "Ուղարկել",
    "Select" : "Select",
    "Move" : "Move",
    "Delete" : "հեռացնել",
    "Choose" : "Ընտրել",
    "Favorites" : "Favorites",
    "Other" : "Այլ",
    "Settings" : "կարգավորումներ",
    "Add folder" : "Add folder",
    "Cancel" : "ընդհատել",
    "General" : "Ընդհանուր",
    "User" : "User",
    "Search" : "Search",
    "Refresh" : "Թարմացնել"
},
"nplurals=2; plural=(n != 1);");
